@@ -761,7 +761,7 @@ impl<'a> RauiRenderer<'a> {
                         .iter()
                         .map(|item| (item.layout.depth, item))
                         .collect::<Vec<_>>();
-                    items.sort_by(|(a, _), (b, _)| a.partial_cmp(&b).unwrap());
+                    items.sort_by(|(a, _), (b, _)| a.partial_cmp(b).unwrap());
                     let local_space = mapping.virtual_to_real_rect(item.local_space, local);
                     let transform = Self::make_transform_command(&unit.transform, local_space);
                     let mask = if unit.clipping {
